import { CommonsHttpUrl } from '../classes/commons-http-url.class';
export function commonsHttpUrlNormalizePath(path) {
    if (path === '')
        return '';
    const firstSlash = path.startsWith('/');
    const segments = path.split('/');
    const rebuild = [];
    for (const segment of segments) {
        if (segment === '')
            continue;
        if (segment === '.')
            continue;
        if (segment === '..') {
            if (rebuild.length > 0)
                rebuild.pop();
            continue;
        }
        rebuild.push(segment);
    }
    if (firstSlash)
        rebuild.unshift('');
    return rebuild.join('/');
}
export function commonsHttpUrlNormalizeRelativeToAbsolute(relative, reference) {
    const referenceUrl = new CommonsHttpUrl(reference);
    referenceUrl.pathname = commonsHttpUrlNormalizePath(referenceUrl.pathname);
    if (/^[a-z]+:\/\//i.test(relative)) {
        // absolute path
        const relativeUrl = new CommonsHttpUrl(relative);
        relativeUrl.pathname = commonsHttpUrlNormalizePath(relativeUrl.pathname);
        return relativeUrl.href;
    }
    if (/^\/\//.test(relative)) {
        // auto-http/s urls
        const relativeUrl = new CommonsHttpUrl(`${referenceUrl.protocol}:${relative}`);
        relativeUrl.pathname = commonsHttpUrlNormalizePath(relativeUrl.pathname);
        return relativeUrl.href;
    }
    if (/^\//.test(relative)) {
        // root urls
        const relativeUrl = new CommonsHttpUrl(`${referenceUrl.origin}${relative}`);
        relativeUrl.pathname = commonsHttpUrlNormalizePath(relativeUrl.pathname);
        return relativeUrl.href;
    }
    let existing = referenceUrl.pathname;
    if (existing !== '' && !existing.endsWith('/')
        && relative !== '' && !/^[?#]/.test(relative)) {
        // assume file, and strip it off, if there is a replacement path file
        const split = existing.split('/');
        split.pop();
        existing = split.join('/');
    }
    { // scope
        const relativeUrl = new CommonsHttpUrl(`${referenceUrl.origin}${existing}${/^[?#]/.test(relative) ? '' : '/'}${relative}`); // queries and anchors aren't counted for relative
        relativeUrl.pathname = commonsHttpUrlNormalizePath(relativeUrl.pathname);
        return relativeUrl.href;
    }
}
//# sourceMappingURL=commons-http-url.js.map