import { TEncodedObject } from 'tscommons-es-core';
import { THttpHeaderOrParamObject } from '../types/thttp-header-or-param-object';
import { TCommonsHttpRequestOptions, TCommonsHttpInternalRequestOptions } from '../types/tcommons-http-request-options';
import { ECommonsHttpContentType } from '../enums/ecommons-http-content-type';
import { ECommonsHttpResponseDataType } from '../enums/ecommons-http-response-data-type';
export declare class CommonsHttpTimeoutError extends Error {
}
export interface ICommonsHttpClientImplementation {
    internalHead(url: string, params: THttpHeaderOrParamObject, headers: THttpHeaderOrParamObject, options: TCommonsHttpInternalRequestOptions): Promise<void>;
    internalGet(url: string, params: THttpHeaderOrParamObject, headers: THttpHeaderOrParamObject, responseDataType: ECommonsHttpResponseDataType, options: TCommonsHttpInternalRequestOptions): Promise<string | Uint8Array>;
    internalPost<B extends TEncodedObject = TEncodedObject>(url: string, body: B, params: THttpHeaderOrParamObject, headers: THttpHeaderOrParamObject, bodyDataEncoding: ECommonsHttpContentType, responseDataType: ECommonsHttpResponseDataType, options: TCommonsHttpInternalRequestOptions): Promise<string | Uint8Array>;
    internalPut<B extends TEncodedObject = TEncodedObject>(url: string, body: B, params: THttpHeaderOrParamObject, headers: THttpHeaderOrParamObject, bodyDataEncoding: ECommonsHttpContentType, responseDataType: ECommonsHttpResponseDataType, options: TCommonsHttpInternalRequestOptions): Promise<string | Uint8Array>;
    internalPatch<B extends TEncodedObject = TEncodedObject>(url: string, body: B, params: THttpHeaderOrParamObject, headers: THttpHeaderOrParamObject, bodyDataEncoding: ECommonsHttpContentType, responseDataType: ECommonsHttpResponseDataType, options: TCommonsHttpInternalRequestOptions): Promise<string | Uint8Array>;
    internalDelete(url: string, params: THttpHeaderOrParamObject, headers: THttpHeaderOrParamObject, responseDataType: ECommonsHttpResponseDataType, options: TCommonsHttpInternalRequestOptions): Promise<string | Uint8Array>;
}
declare type TReattemptDebugCallback = (reattempt: number, url: string, params: TEncodedObject | undefined, headers: TEncodedObject | undefined, options: TCommonsHttpRequestOptions | undefined) => void;
export declare class CommonsHttpClientService {
    private implementation;
    private static buildHeadersOrParams;
    private static appendContentType;
    private reattemptDebugCallback;
    constructor(implementation: ICommonsHttpClientImplementation);
    setReattemptDebugCallback(callback: TReattemptDebugCallback): void;
    head<P extends TEncodedObject = TEncodedObject, H extends TEncodedObject = TEncodedObject>(url: string, params?: P | undefined, // the params can be explicitly undefined (none) as well as optional
    headers?: H | undefined, // the headers can be explicitly undefined (none) as well as optional,
    options?: TCommonsHttpRequestOptions): Promise<void>;
    get<P extends TEncodedObject = TEncodedObject, H extends TEncodedObject = TEncodedObject>(url: string, params?: P | undefined, // the params can be explicitly undefined (none) as well as optional
    headers?: H | undefined, // the headers can be explicitly undefined (none) as well as optional
    options?: TCommonsHttpRequestOptions): Promise<string | Uint8Array>;
    post<B extends TEncodedObject = TEncodedObject, P extends TEncodedObject = TEncodedObject, H extends TEncodedObject = TEncodedObject>(url: string, body: B, params?: P | undefined, // the params can be explicitly undefined (none) as well as optional
    headers?: H | undefined, // the headers can be explicitly undefined (none) as well as optional
    options?: TCommonsHttpRequestOptions): Promise<string | Uint8Array>;
    put<B extends TEncodedObject = TEncodedObject, P extends TEncodedObject = TEncodedObject, H extends TEncodedObject = TEncodedObject>(url: string, body: B, params?: P | undefined, // the params can be explicitly undefined (none) as well as optional
    headers?: H | undefined, // the headers can be explicitly undefined (none) as well as optional
    options?: TCommonsHttpRequestOptions): Promise<string | Uint8Array>;
    patch<B extends TEncodedObject = TEncodedObject, P extends TEncodedObject = TEncodedObject, H extends TEncodedObject = TEncodedObject>(url: string, body: B, params?: P | undefined, // the params can be explicitly undefined (none) as well as optional
    headers?: H | undefined, // the headers can be explicitly undefined (none) as well as optional
    options?: TCommonsHttpRequestOptions): Promise<string | Uint8Array>;
    delete<P extends TEncodedObject = TEncodedObject, H extends TEncodedObject = TEncodedObject>(url: string, params?: P | undefined, // the params can be explicitly undefined (none) as well as optional
    headers?: H | undefined, // the headers can be explicitly undefined (none) as well as optional
    options?: TCommonsHttpRequestOptions): Promise<string | Uint8Array>;
}
export {};
